=================================================================
``psyclone.psyir.transformations.intrinsics.minormax2code_trans``
=================================================================

.. automodule:: psyclone.psyir.transformations.intrinsics.minormax2code_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.intrinsics.minormax2code_trans
